==> react-native-highlight-words-1.0.2.tgz: react-native-highlight-words/README.md <==
# Installation
> `npm install --save @types/react-native-highlight-words`

# Summary
This package contains type definitions for react-native-highlight-words (https://github.com/clauderic/react-native-highlight-words).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-native-highlight-words.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-native-highlight-words/index.d.ts)
````ts
// Type definitions for react-native-highlight-words 1.0
// Project: https://github.com/clauderic/react-native-highlight-words
// Definitions by: Ivan Stelmakh <https://github.com/stelmakhivan>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

import * as React from 'react';
import { TextProps } from 'react-native';

export interface HighlighterProps extends TextProps {
    autoEscape?: boolean | undefined;
    highlightStyle?: TextProps['style'] | undefined;
    sanitize?: ((text: string) => string) | undefined;
    searchWords: string[];
    style?: TextProps['style'] | undefined;
    textToHighlight: string;
}

export default class Highlighter extends React.Component<HighlighterProps> {}

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 20:21:04 GMT
 * Dependencies: [@types/react](https://npmjs.com/package/@types/react), [@types/react-native](https://npmjs.com/package/@types/react-native)
 * Global values: none

# Credits
These definitions were written by [Ivan Stelmakh](https://github.com/stelmakhivan).

==> react-native-highlight-words-1.0.3.tgz: react-native-highlight-words/README.md <==
# Installation
> `npm install --save @types/react-native-highlight-words`

# Summary
This package contains type definitions for react-native-highlight-words (https://github.com/clauderic/react-native-highlight-words).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-native-highlight-words.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-native-highlight-words/index.d.ts)
````ts
// Type definitions for react-native-highlight-words 1.0
// Project: https://github.com/clauderic/react-native-highlight-words
// Definitions by: Ivan Stelmakh <https://github.com/stelmakhivan>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

import * as React from "react";
import { TextProps } from "react-native";

export interface HighlighterProps extends TextProps {
    autoEscape?: boolean | undefined;
    highlightStyle?: TextProps["style"] | undefined;
    sanitize?: ((text: string) => string) | undefined;
    searchWords: string[];
    style?: TextProps["style"] | undefined;
    textToHighlight: string;
}

export default class Highlighter extends React.Component<HighlighterProps> {}

````

### Additional Details
 * Last updated: Wed, 27 Sep 2023 07:12:04 GMT
 * Dependencies: [@types/react](https://npmjs.com/package/@types/react), [@types/react-native](https://npmjs.com/package/@types/react-native)
 * Global values: none

# Credits
These definitions were written by [Ivan Stelmakh](https://github.com/stelmakhivan).
